@@ -32,8 +32,8 @@ selinux_enabled () {
 }
 
 # Read /etc/fstab, looking for:
-# 1) The root filesystem, resolving LABEL=*|UUID=* entries to the
-#	device node,
+# 1) The root filesystem, resolving LABEL=*|UUID=*|PARTUUID=*|PARTLABEL=* entries
+#	to the device node,
 # 2) Swap that is on a md device or a file that may be on a md
 #	device,
 _read_fstab () {
@@ -58,7 +58,7 @@ _read_fstab () {
 					;;
 				  /dev/*)
 					;;
-				  LABEL=*|UUID=*)
+				  LABEL=*|UUID=*|PARTUUID=*|PARTLABEL=*)
 					if [ "$MTPT" = "/" ] && [ -x /sbin/findfs ]
 					then
 						DEV="$(findfs "$DEV")"
@@ -87,11 +87,17 @@ _read_fstab () {
 	done
 }
 
-# Read /etc/fstab, looking for:
-# 1) The root filesystem, resolving LABEL=*|UUID=* entries to the
-#	device node,
-# 2) Swap that is on a md device or a file that may be on a md
-#	device,
+# Parse /etc/fstab and set variables relating to:
+# 1) The root filesystem:
+#    - rootdev
+#    - fstabroot
+#    - rootopts
+#    - roottype
+#    - rootcheck
+#    - rootmode
+# 2) Swap:
+#    - swap_on_file
+#    - swap_on_lv
 
 read_fstab () {
 	eval "$(_read_fstab)"
@@ -272,7 +278,7 @@ domount () {
 					is_empty_dir "$MTPT" >/dev/null 2>&1 || log_warning_msg "Files under mount point '$MTPT' will be hidden."
 				fi
 				mount $MOUNTFLAGS -t $FSTYPE $CALLER_OPTS $FSTAB_OPTS $FS_OPTS $DEVNAME $MTPT
-				if [ "$FSTYPE" = "tmpfs" -a -x /sbin/restorecon ]; then
+				if [ "$FSTYPE" = "tmpfs" ] && [ -x /sbin/restorecon ]; then
 					/sbin/restorecon $MTPT
 				fi
 			fi
@@ -718,10 +724,11 @@ is_fastboot_active() {
 
 # This function does not actually belong here; it is duct-tape solution
 # for #901289.
-logsave_best_effort () {
-	if [ -x /sbin/logsave ] ; then
+logsave_best_effort() {
+	if [ -x /sbin/logsave ] && [ -e "${FSCK_LOGFILE}" ]; then
 		logsave -s "${FSCK_LOGFILE}" "$@"
 	else
+		log_failure_msg "Cannot persist the following output on disc"
 		"$@"
 	fi
 }
